@@ -1,7 +1,7 @@
 package Tapper::Cmd::Init;
 our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: Tapper - Backend functions for initially setting up Tapper
-$Tapper::Cmd::Init::VERSION = '5.0.3';
+$Tapper::Cmd::Init::VERSION = '5.0.4';
 use 5.010;
 use strict;
 use warnings;
@@ -135,6 +135,7 @@ sub init
         make_subdir my $pkg_dir      = "$HOME/.tapper/repository/packages";
         make_subdir my $prg_dir      = "$HOME/.tapper/testprogram";
         make_subdir my $producer_dir = "$HOME/.tapper/producers";
+        make_subdir my $precond_dir  = "$HOME/.tapper/macropreconditions";
         make_subdir my $localdata_dir = "$HOME/.tapper/localdata";
 
         copy_subdir ($init_dir, "hello-world");
@@ -143,9 +144,12 @@ sub init
         mint_file ($init_dir, "log4perl.cfg");
         mint_file ($init_dir, "log4perl_webgui.cfg");
         mint_file ($init_dir, "tapper-mcp-messagereceiver.conf");
+        mint_file ($init_dir, "testprogram/tapper-selftest.sh");
 
-        # Allow more fine-grained updates for testplans,
+        # Allow more fine-grained updates for testplans and macropreconditions,
         # as we expect the user to have his own stuff in there.
+        mint_file ($init_dir, $_) foreach qw(macropreconditions/tapper-selftest.mpc);
+
         make_subdir my $tplan_dir = "$HOME/.tapper/testplans";
 
         make_subdir "$tplan_dir/$_" foreach qw(topic
@@ -156,6 +160,7 @@ sub init
                                                topic/kernel
                                                topic/kernel/generic
                                                topic/helloworld
+                                               topic/tapper
                                                include
                                              );
         mint_file ($init_dir, $_) foreach qw(testplans/topic/xen/generic/upload-xen-dmesg.sh
@@ -167,6 +172,7 @@ sub init
                                              testplans/topic/helloworld/example01
                                              testplans/topic/helloworld/example02
                                              testplans/topic/helloworld/example03-builder
+                                             testplans/topic/tapper/tapper-selftest
                                              testplans/include/distrodetails
                                              testplans/include/defaults
                                              testplans/include/defaultbenchmarks
